@@ -661,17 +661,22 @@ class GitLibMixin:
             raise ValueError(f"Remote {remote} does not exist")
 
     def pushToRemote(
-        self, remote: str, username: str, password: str = None
+        self, remoteName: str, username: str, password: str = None
     ) -> None:
-        if remote not in [r[0] for r in self.allRemotes()]:
-            raise NoRemoteDefined(f"Remote {remote} not set for project")
+        if remoteName not in [r[0] for r in self.allRemotes()]:
+            raise NoRemoteDefined(f"Remote {remoteName} not set for project")
 
-        if password is None:
+        logger.info("Pulling in remote changes before Pushing")
+        self.pullFromRemote(remoteName, username, password)
+
+        if not username:
+            cred = None
+        elif not password:
             cred = pygit2.Username(username)
         else:
             cred = pygit2.UserPass(username, password)
 
-        remote = self._repo.remotes[remote]
+        remote = self._repo.remotes[remoteName]
 
         class RemoteCallback(RemoteCallbacks):
             def credentials(self, url, username_from_url, allowed_types):
@@ -681,18 +686,41 @@ class GitLibMixin:
                 # Return whatever the TLS/SSH library thinks about the cert
                 return True
 
+        checkedOutBranch = self.__checkedOutBranch
+        remoteBranchName = f"{remoteName}/{checkedOutBranch.shorthand}"
+        remoteBranch = self._repo.branches[remoteBranchName]
+
+        if checkedOutBranch.target == remoteBranch.target:
+            raise Exception("There are no commits to push")
+
+        # TODO: This does not seem to raise any errors when a push was
+        #  unsuccessful due to permission errors
         remote.push(
-            [self.__checkedOutBranch.name],
+            [checkedOutBranch.name],
             callbacks=RemoteCallback(),
         )
 
+        # Check if the push was successful
+        remote = self._repo.remotes[remoteName]
+        remote.fetch(callbacks=RemoteCallback())
+        # Reload the remoteBranch reference
+        remoteBranch = self._repo.branches[remoteBranchName]
+
+        if remoteBranch.target != checkedOutBranch.target:
+            raise Exception(
+                "Remote rejected push. Please check if you have permissions "
+                "to push to the remote or file sizes in Git are not too big"
+            )
+
     def pullFromRemote(
         self, remoteName: str, username: str, password: str = None
     ) -> None:
         if remoteName not in [r[0] for r in self.allRemotes()]:
             raise NoRemoteDefined(f"Remote {remoteName} not set for project")
 
-        if password is None:
+        if not username:
+            cred = None
+        elif not password:
             cred = pygit2.Username(username)
         else:
             cred = pygit2.UserPass(username, password)
