@@ -5,6 +5,12 @@ from vortex.Tuple import TupleField
 from vortex.Tuple import addTupleType
 
 
+STAT_DELETED = "D"
+STAT_MODIFIED = "M"
+STAT_ADDED = "A"
+STAT_RENAMED = "R"
+
+
 @addTupleType
 class ModifiedItemDetails(Tuple):
     __tupleType__ = "attune_auto_project.ModifiedItemDetails"
@@ -13,11 +19,10 @@ class ModifiedItemDetails(Tuple):
     name: str = TupleField()
     # Indicates the change to an item from the Git diff
     # Example 'M' for modified, 'D' for deleted and so on...
-    # TODO: Document all the possibilities and use fixed named constants
     changeStatus: str = TupleField()
 
     # Hash and Equals based on key because we want each item to only appear
-    # once in the change list.
+    # once in the change set.
     def __hash__(self) -> int:
         return hash(self.key)
 
